@@ -50,7 +50,8 @@ functional hash tables implementation (like the one used by Clojure)?)
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
