@@ -19,7 +19,12 @@ FP::Lazy - lazy evaluation (delayed evaluation, promises)
     eval {
         print force $a
     };
-    like $@, qr/division by zero/;
+    like $@, qr/^Illegal division by zero/;
+
+    eval {
+        $a + 2
+    };
+    like $@, qr/^non-auto-forcing promise accessed via 0\+ operation/;
 
     my $count= 0;
     my $b = lazy { $count++; 1 / 2 };
@@ -79,7 +84,7 @@ FP::Lazy - lazy evaluation (delayed evaluation, promises)
         # the overhead of two subroutine calls, though)
         condprom 0
     };
-    like $@, qr/division by zero/;
+    like $@, qr/^Illegal division by zero/;
 
 
 =head1 DESCRIPTION
@@ -159,9 +164,12 @@ Alternative Scalar::Defer?
 
 L<FP::TransparentLazy>
 
+L<FP::Mixin::Utils> -- Lazy implements this as a fallback (lower priority than forcing the promise and finding the method on the result)
+
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
@@ -174,6 +182,10 @@ package FP::Lazy;
 
 use strict; use warnings; use warnings FATAL => 'uninitialized';
 
+use Carp;
+use FP::Mixin::Utils;
+
+
 our $debug= $ENV{DEBUG_FP_LAZY} ? 1 : '';
 
 # A promise is an array with two fields:
@@ -186,7 +198,7 @@ sub lazy (&) {
            undef,
            $debug && FP::Repl::Stack->get(1)->backtrace
           ], "FP::Lazy::Promise"
-      }
+}
 
 sub lazy_if (&$) {
     ($_[1] ?
@@ -207,7 +219,7 @@ sub lazyLight (&) {
 }
 
 sub is_promise ($) {
-    length ref $_[0] ? UNIVERSAL::isa ($_[0], "FP::Lazy::Promise") : ''
+    length ref $_[0] ? UNIVERSAL::isa ($_[0], "FP::Lazy::AnyPromise") : ''
 }
 
 sub delay (&);  *delay = \&lazy;
@@ -269,15 +281,41 @@ sub FORCE {
     wantarray ? @_ : $_[-1]
 }
 
-{
-    package FP::Lazy::Promise;
+
+# `use overload` arguments, to prevent from accidental use as if it
+# were FP::TransparentLazy
+
+our $allow_access= 0; # true 'turns off' the overload
+
+sub overloads {
+    my ($with_application_overload)= @_;
+    ((map {
+        my $ctx= $_;
+        $ctx=> sub {
+            $allow_access ? $_[0] :
+                Carp::croak "non-auto-forcing promise accessed via $ctx operation"
+        }
+      }
+      ($with_application_overload ? ("&{}") : ()),
+      # (XX can't overload '@{}'?)
+      qw(0+ "" bool qr ${} %{} *{})
+     ),
+     fallback=> 1
+    )
+}
+
+package FP::Lazy::AnyPromise {
+
     *force= *FP::Lazy::force;
+
     sub FORCE {
         $_[0] = force ($_[0]);
     }
+
     sub DESTROY {
         # nothing, catch this to prevent it from entering AUTOLOAD
     }
+
     our $AUTOLOAD; # needs to be declared even though magical
     sub AUTOLOAD {
         my $methodname= $AUTOLOAD;
@@ -290,7 +328,8 @@ sub FORCE {
         my $method=
           ($methodname=~ /^stream_/ ? UNIVERSAL::can($v, $methodname)
            : UNIVERSAL::can($v, "stream_$methodname")
-             // UNIVERSAL::can($v, $methodname));
+           // UNIVERSAL::can($v, $methodname)
+           // UNIVERSAL::can("FP::Mixin::Utils", $methodname));
         if ($method) {
             # can't change @_ or it would break 'env clearing' ability
             # of the method. Thus assign to $_[0], which will effect
@@ -298,18 +337,27 @@ sub FORCE {
             $_[0]= $v; goto &$method;
         } else {
             # XX imitate perl's ~exact error message?
-            die "no method '$methodname' found for object: $v";
+            Carp::croak "no method '$methodname' found for object: $v";
         }
     }
 
     # should really have a maybe_ prefix, but since it's for debugging
     # purposes only (and in that case also likely always returns a
     # value) and we like short names for that, leave it at this, ok?
+    # XXX avoid spamming with such a short name; use FP_Lazy_bt [or
+    # de-priorize it like the FP::Mixin::Utils stuff?]
     sub bt {
         my $s=shift;
         $$s[2]
     }
 
+}
+
+package FP::Lazy::Promise {
+    our @ISA= 'FP::Lazy::AnyPromise';
+
+    use overload FP::Lazy::overloads(1);
+
     sub FP_Show_show {
         my ($s,$show)=@_;
         # do not force unforced promises
@@ -321,9 +369,11 @@ sub FORCE {
     }
 }
 
-{
-    package FP::Lazy::PromiseLight;
-    our @ISA= qw(FP::Lazy::Promise);
+
+package FP::Lazy::PromiseLight {
+    our @ISA= qw(FP::Lazy::AnyPromise);
+
+    use overload FP::Lazy::overloads(0);
 
     sub FP_Show_show {
         my ($s,$show)=@_;
