@@ -68,7 +68,8 @@ L<FP::List>, L<FP::Ops>, L<FP::Array>, L<FP::PureArray>
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
